┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphincolumnview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphincolumnview.h')
-rw-r--r--src/dolphincolumnview.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/dolphincolumnview.h b/src/dolphincolumnview.h
index a3290cc2c..03f210229 100644
--- a/src/dolphincolumnview.h
+++ b/src/dolphincolumnview.h
@@ -73,10 +73,19 @@ private:
/**
* Requests the activation for the column \a column. The URL
* navigator will be changed to represent the column.
*/
void requestActivation(QWidget* column);
+ /**
+ * Requests the selection model from the Column View for \a view.
+ * If another column has already obtained the Column View selection
+ * model, it will be replaced by a default selection model.
+ */
+ void requestSelectionModel(QAbstractItemView* view);
+
private:
DolphinController* m_controller;
@@ -73,10 +73,19 @@ private:
/**
* Requests the activation for the column \a column. The URL
- * navigator will be changed to represent the column.
+ * navigator will be changed to represent the column. It is
+ * assured that the selection model of \a column will be set
+ * to the selection model of the Column View.
*/
void requestActivation(QWidget* column);